Mixed-Up Code Questions
------------------------

.. selectquestion:: bsoup_mixedupcode_1_sq_v2
   :fromid: bsoup_mixedupcode_1, bsoup_mixedupcode_1_ac_v2
   :toggle:


.. selectquestion:: bsoup_mixedupcode_2_sq_v2
   :fromid: bsoup_mixedupcode_2, bsoup_mixedupcode_2_ac_v2
   :toggle:


.. selectquestion:: bsoup_mixedupcode_3_sq_v2
   :fromid: bsoup_mixedupcode_3, bsoup_mixedupcode_3_ac_v2
   :toggle:


.. selectquestion:: bsoup_mixedupcode_4_sq_v2
   :fromid: bsoup_mixedupcode_4, bsoup_mixedupcode_4_ac_v2
   :toggle:


.. selectquestion:: bsoup_mixedupcode_5_sq_v2
   :fromid: bsoup_mixedupcode_5, bsoup_mixedupcode_5_ac_v2
   :toggle:

.. selectquestion:: bsoup_mixedupcode_6_sq_v2
  :fromid: bsoup_mixedupcode_6, bsoup_mixedupcode_6_ac_v2
  :toggle:


.. selectquestion:: bsoup_mixedupcode_7_sq_v2
  :fromid: bsoup_mixedupcode_7, bsoup_mixedupcode_7_ac_v2
  :toggle:


.. selectquestion:: bsoup_mixedupcode_8_sq_v2
  :fromid: bsoup_mixedupcode_8, bsoup_mixedupcode_8_ac_v2
  :toggle:
